@@ -1,28 +1,12 @@
-# Pure zero-dependency JSON-RPC 2.0 implementation.
-# Copyright © 2022-2023 Andrew Malchuk. All rights reserved.
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     https://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
 from collections.abc import MutableSequence
 from dataclasses import is_dataclass
 from functools import partial
 from typing import Final
-from unittest.case import TestCase
+from unittest import TestCase
 from uuid import UUID, uuid4
 
-from jsonrpc._errors import Error, ErrorEnum
-from jsonrpc._response import BatchResponse, Response
-from jsonrpc._utilities import Undefined
+from jsonrpc import BatchResponse, Error, ErrorEnum, Response
+from jsonrpc.utilities import Undefined
 
 
 class TestResponse(TestCase):
